Environments
============
|
An environment defines where to deploy StreamSets engines, and represents the resources needed to run the engines.

For more details, refer to the `StreamSets Platform Documentation <https://docs.streamsets.com/portal/#platform-controlhub/controlhub/UserGuide/Environments/Environments_title.html>`_.

.. toctree::
   :maxdepth: 3
   :hidden:

   self_managed_environments
   aws_environments
   azure_environments
   gcp_environments
   kubernetes_environments
   managing_environments
